%global major           4
%define libname         %mklibname %{name} %{major}
%define devname         %mklibname %{name} -d

%global gettext_package FontForge

Name:           fontforge
Version:        20230101
Release:        %mkrel 5
Summary:        Font Editor for PostScript, TrueType, OpenType and various fonts
License:        GPLv3+
Group:          Publishing
URL:            https://fontforge.github.io
Source0:        https://github.com/fontforge/fontforge/archive/%{version}/%{name}-%{version}.tar.gz
# Remove tests that requires Internet access
Patch0:         fontforge-20201107-remove-internet-tests.patch
Patch1:         5367.patch
Patch2:         642d8a3db6d4bc0e70b429622fdf01ecb09c4c10.patch

BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  gettext
BuildRequires:  giflib-devel
BuildRequires:  git
BuildRequires:  libltdl-devel
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gdk-3.0)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libspiro)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(libuninameslist)
BuildRequires:  pkgconfig(libwoff2enc)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(readline)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xproto)
BuildRequires:  pkgconfig(xt)
BuildRequires:  python3-sphinx
BuildRequires:  shared-mime-info
BuildRequires:  uthash-devel

Provides:       bundled(gnulib)

%description
FontForge is a font editor for outline and bitmap fonts. Use it to create, edit
and convert fonts in OpenType, TrueType, UFO, CID-keyed, Multiple Master, and
many other formats.

%package -n     %{libname}
Summary:        Development tools for fontforge
Group:          System/Libraries
Conflicts:      %{name} < 20201107-3
Obsoletes:      %{_lib}fontforge-devel < 20201107-3

%description -n %{libname}
This package includes the shared libraries for fontforge.

%package -n     %{devname}
Summary:        Development tools for fontforge
Group:          Development/Other
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{devname}
This package includes the libraries and header files you will need
to compile applications against fontforge.

%package doc
Summary: Documentation files for %{name}
Group: Documentation
BuildArch: noarch

%description doc
This package contains documentation files for %{name}

%prep
%autosetup -p1

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%cmake
%cmake_build

%install
%cmake_install

# drop presumably unneeded devel pkg
rm -rf %{buildroot}%{_libdir}/libfontforge.so

# Find translations
%find_lang %{gettext_package}

%files -f %{gettext_package}.lang
%license LICENSE
%{_bindir}/font*
%{_bindir}/sfddiff
%{_datadir}/%{name}/
%{_datadir}/applications/org.%{name}.FontForge.desktop
%{_datadir}/metainfo/org.%{name}.FontForge.appdata.xml
%{_datadir}/mime/packages/%{name}.xml
%{_iconsdir}/hicolor/*/apps/org.%{name}.FontForge.*
%{_mandir}/man1/*.1*
%{python3_sitearch}/%{name}.so
%{python3_sitearch}/psMat.so

%files -n %{libname}
%{_libdir}/libfontforge.so.%{major}{,.*}

%if 0
%files -n %{devname}
%{_libdir}/libfontforge.so
%endif

%files doc
%doc %{_pkgdocdir}


%changelog
* Sun Mar 16 2025 wally <wally> 20230101-5.mga10
+ Revision: 2164791
- rebuild for libxml2 2.13.6

* Sat Mar 01 2025 daviddavid <daviddavid> 20230101-4.mga10
+ Revision: 2154001
- rebuild for python 3.13

* Tue Mar 19 2024 ns80 <ns80> 20230101-3.mga10
+ Revision: 2050856
- add an upstream patch to fix po files
- add upstream patch for CVE-2024-2508[12] (mga#32956)

* Wed Dec 27 2023 daviddavid <daviddavid> 20230101-2.mga10
+ Revision: 2022533
- rebuild for py3.12

* Wed Nov 01 2023 daviddavid <daviddavid> 20230101-1.mga10
+ Revision: 2003355
- new version: 20230101

* Mon Dec 12 2022 ns80 <ns80> 20220308-2.mga9
+ Revision: 1921006
- rebuild for new libtiff

* Thu Oct 06 2022 neoclust <neoclust> 20220308-1.mga9
+ Revision: 1895085
- New version 20220308

* Thu Mar 31 2022 umeabot <umeabot> 20201107-5.mga9
+ Revision: 1835735
- Mageia 9 Mass Rebuild

* Sun Feb 13 2022 tv <tv> 20201107-4.mga9
+ Revision: 1773722
- Rebuild for python-3.10

* Sun Jul 18 2021 wally <wally> 20201107-3.mga9
+ Revision: 1736584
- update description
- split out lib pkg
- drop presumably unneeded devel pkg
- add rpm groups
- build using our default cmake build type (RelWithDebInfo)

* Sat Mar 20 2021 daviddavid <daviddavid> 20201107-2.mga9
+ Revision: 1705917
- rebuild for python 3.9

* Wed Dec 30 2020 akien <akien> 20201107-1.mga8
+ Revision: 1665671
- Version 20201107

* Thu Oct 29 2020 joequant <joequant> 20200314-1.mga8
+ Revision: 1640508
- add sphinx
- update deps
- add cmake
- update to 20200314

* Wed Feb 19 2020 umeabot <umeabot> 20190801-6.mga8
+ Revision: 1543550
- Mageia 8 Mass Rebuild

* Tue Jan 21 2020 ns80 <ns80> 20190801-5.mga8
+ Revision: 1481901
- add upstream patch for  CVE-2020-5395 and CVE-2020-5496 (mga#26095)
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Jan 04 2020 tv <tv> 20190801-4.mga8
+ Revision: 1476443
- rebuild with new readline

* Tue Oct 29 2019 daviddavid <daviddavid> 20190801-3.mga8
+ Revision: 1456482
- rebuild for new libspiro 20190731

* Tue Sep 10 2019 wally <wally> 20190801-2.mga8
+ Revision: 1439407
- rebuild for python3.8

* Tue Aug 20 2019 daviddavid <daviddavid> 20190801-1.mga8
+ Revision: 1430519
- new version: 20190801

* Sun Apr 21 2019 akien <akien> 20190413-1.mga7
+ Revision: 1394570
- Version 20190413

* Tue Jan 08 2019 tv <tv> 20170731-8.mga7
+ Revision: 1352478
- rebuild with python 3.7

* Sun Sep 23 2018 umeabot <umeabot> 20170731-7.mga7
+ Revision: 1297739
- Mageia 7 Mass Rebuild

* Tue Jan 02 2018 wally <wally> 20170731-6.mga7
+ Revision: 1189426
- rebuild for new readline

* Sat Aug 05 2017 pterjan <pterjan> 20170731-5.mga7
+ Revision: 1135211
- Rebuild for python 3.6

* Mon Jul 31 2017 shlomif <shlomif> 20170731-4.mga7
+ Revision: 1133268
- New version 201707

* Fri Jun 30 2017 shlomif <shlomif> 20161012-4.mga6
+ Revision: 1108750
- Get rid of the autotrace dep, because we're deprecating autotrace.
  It is optional anyway.

* Sat Feb 04 2017 wally <wally> 20161012-3.mga6
+ Revision: 1084816
- drop requires that are already pulled via autoreqs

* Thu Feb 02 2017 daviddavid <daviddavid> 20161012-2.mga6
+ Revision: 1084613
- rebuild for new libuninameslist

* Sun Jan 29 2017 akien <akien> 20161012-1.mga6
+ Revision: 1084100
- Version 20161012 (partial sync with Fedora)
- Use python3 instead of python2

* Tue Sep 20 2016 ghibo <ghibo> 20160404-1.mga6
+ Revision: 1054583
- Fix permission of FontForgeSplash.png in docs
- New release 20160404

* Sun Jan 10 2016 daviddavid <daviddavid> 20150824-4.mga6
+ Revision: 921204
- rebuild for new giflib 5.1.2

* Tue Nov 24 2015 tv <tv> 20150824-3.mga6
+ Revision: 905703
- BR spiro-devel

* Mon Nov 23 2015 daviddavid <daviddavid> 20150824-2.mga6
+ Revision: 905283
- install all icons manually (workaround to fix build)
- remove invalid Requires on fontforge-doc
- fix Release tag
- add a mime-package file and an appdata file
+ tv <tv>
- further reduce diff with FC
- require autorace instead of fonttracer
- reduce diff with FC
- use bundled desktop entry
- kill BR on libx11-devel

* Wed Nov 18 2015 tv <tv> 20150824-1.20120731.10.mga6
+ Revision: 904091
- adjust file list + create devel pkg
- package libs

* Wed Nov 18 2015 tv <tv> 20150824-1.20120731.9.mga6
+ Revision: 904075
- BR libltdl-devel
- add more BRs
- BR git
- fix SOURCE1 URL for mgarepo sync
- new release

* Wed Oct 15 2014 umeabot <umeabot> 1.0-1.20120731.9.mga5
+ Revision: 741428
- Second Mageia 5 Mass Rebuild

* Fri Sep 26 2014 tv <tv> 1.0-1.20120731.8.mga5
+ Revision: 725052
- rebuild for bogus file deps

* Tue Sep 16 2014 umeabot <umeabot> 1.0-0.20120731.8.mga5
+ Revision: 679255
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 1.0-0.20120731.7.mga4
+ Revision: 526399
- Mageia 4 Mass Rebuild

* Tue Jun 04 2013 fwang <fwang> 1.0-0.20120731.6.mga4
+ Revision: 436903
- we are now providing libpng16

* Mon Jun 03 2013 tv <tv> 1.0-0.20120731.5.mga4
+ Revision: 436312
- rebuild for new libpng

* Mon Jun 03 2013 fwang <fwang> 1.0-0.20120731.4.mga4
+ Revision: 435854
- rebuild for new libpng

* Fri Jan 11 2013 umeabot <umeabot> 1.0-0.20120731.3.mga3
+ Revision: 350654
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Oct 08 2012 tv <tv> 1.0-0.20120731.2.mga3
+ Revision: 303409
- BR x11-devel
- add patch from opensuse not to look for libpng.so.2
- requires libpng

* Tue Sep 11 2012 shlomif <shlomif> 1.0-0.20120731.1.mga3
+ Revision: 292435
- New version - 20120731-b

* Thu May 10 2012 doktor5000 <doktor5000> 1.0-0.20110222.3.mga2
+ Revision: 235150
- remove unneeded explicit Require on mfwin/texlive (mga#5812)

* Thu Oct 27 2011 doktor5000 <doktor5000> 1.0-0.20110222.2.mga2
+ Revision: 158591
- updated fontforge-tutorial.pdf
- updated cidmaps tarball, use upstream tarball, don't recompress
- added back local-helpdir.patch and properly renamed it
- removed unrecognized configure options
- use %%make macro
- removed deprecated %%clean section

* Sun Jun 19 2011 spuhler <spuhler> 1.0-0.20110222.1.mga2
+ Revision: 109560
- upgraded version to	20110222
  upgraded docversion	20110221
  removed Patch1: fontforge-%%{version}-local-helpdir.patch

* Tue Apr 26 2011 wally <wally> 1.0-0.20090923.5.mga1
+ Revision: 91662
- fix desktop file (mga#954)
- drop buildroot definition

* Fri Mar 04 2011 boklm <boklm> 1.0-0.20090923.4.mga1
+ Revision: 64137
- require mfwin instead of tetex-mfwin

* Mon Jan 17 2011 pterjan <pterjan> 1.0-0.20090923.3.mga1
+ Revision: 21122
- Drop obsolete scriptlets
- imported package fontforge


* Thu Dec 02 2010 Oden Eriksson <oeriksson@mandriva.com> 1.0-0.20090923.3mdv2011.0
+ Revision: 605181
- rebuild

* Wed Mar 17 2010 Oden Eriksson <oeriksson@mandriva.com> 1.0-0.20090923.2mdv2010.1
+ Revision: 522653
- rebuilt for 2010.1

* Sun Sep 27 2009 Frederik Himpe <fhimpe@mandriva.org> 1.0-0.20090923.1mdv2010.0
+ Revision: 449729
- Update to new version 20090923

* Wed Sep 16 2009 Frederik Himpe <fhimpe@mandriva.org> 1.0-0.20090914.1mdv2010.0
+ Revision: 443643
- Update to new version 20090914
- Remove string format patch and segfault patch: fixed upstream

* Thu May 14 2009 Frederik Himpe <fhimpe@mandriva.org> 1.0-0.20090408.1mdv2010.0
+ Revision: 375761
- Update to new version 20090408
- Add some Debian patches:
  * Use grey background
  * Link with libgif
  * Segmentation fault fix

* Sat Mar 14 2009 Emmanuel Andry <eandry@mandriva.org> 1.0-0.20090224.1mdv2009.1
+ Revision: 355093
- New version 20090224
- update docs
- diff P2 to fix string format not literal

* Fri Sep 05 2008 Emmanuel Andry <eandry@mandriva.org> 1.0-0.20080828.1mdv2009.0
+ Revision: 281388
- New version

* Tue Jun 17 2008 Thierry Vignaud <tv@mandriva.org> 1.0-0.20071210.1mdv2009.0
+ Revision: 222751
- fix 'Installed (but unpackaged) file(s) found'
- parallel build is broken
- kill re-definition of %%buildroot on Pixel's request

  + Pixel <pixel@mandriva.com>
    - rpm filetriggers deprecates update_menus/update_scrollkeeper/update_mime_database/update_icon_cache/update_desktop_database/post_install_gconf_schemas

  + Giuseppe Ghibò <ghibo@mandriva.com>
    - Release 20071210.

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Sat Oct 13 2007 Giuseppe Ghibò <ghibo@mandriva.com> 1.0-0.20071002.1mdv2008.1
+ Revision: 97895
- Release: 20071002.

* Tue Sep 04 2007 Adam Williamson <awilliamson@mandriva.org> 1.0-0.20070831.1mdv2008.0
+ Revision: 79024
- fd.o icons
- drop old menu file and X-Mandriva XDG category
- use draft license policy (-like, not Style)
- new snapshot 20070831


* Sat Feb 24 2007 Giuseppe Ghibò <ghibo@mandriva.com> 1.0-0.20061220.2mdv2007.0
+ Revision: 125431
- Added Patch0 so to avoid libuninameslist-devel into Requires.
- Added Patch1 for local helpdir.
- Added libxml2-devel to BuildRequires.

* Sun Jan 21 2007 David Walluck <walluck@mandriva.org> 1.0-0.20061220.1mdv2007.1
+ Revision: 111228
- 20061220

* Thu Aug 24 2006 Per Øyvind Karlsen <pkarlsen@mandriva.com> 1.0-0.20060715.2mdv2007.0
+ Revision: 57538
- fix xdg menu (categories, name, comment)
- use %%find_lang for translations
- remove rpath
- don't bzip2 icons
- drop redundant doc dir

* Fri Aug 11 2006 Bruno Cornec <Bruno.Cornec@mandriva.org> 1.0-0.20060715.1mdv2007.0
+ Revision: 55478
- THanks to F. Crozat for the remark anbout the forgotten \
- desktop file was not in %%files
- XDG compliance added following http://qa.mandriva.com/twiki/bin/view/Main/MenuMigrationToXDG
- Updated to 20060715
  Patches not used anymore but stil in SVN for now in case I missed something.
- import fontforge-1.0-0.20060125.2mdk

* Mon May 15 2006 Stefan van der Eijk <stefan@eijk.nu> 1.0-0.20060125.2mdk
- rebuild for sparc

* Sat Feb 04 2006 Giuseppe Ghibò <ghibo@mandriva.com> 1.0-0.20060125.1mdk
- Release: 20060125.
- Added PDF tutorial.

* Wed Dec 28 2005 Giuseppe Ghibò <ghibo@mandriva.com> 1.0-0.20051205.1mdk
- Release: 20051202.
- Rebuilt Patch1.

* Sat Nov 26 2005 Thierry Vignaud <tvignaud@mandriva.com> 1.0-0.20051023.2mdk
- fix menu entry (#14732)

* Thu Oct 27 2005 Abel Cheung <deaddog@mandriva.org> 1.0-0.20051023.1mdk
- Release: 20051023.
- Adapted Patch1 (partially merged upstream).

* Thu Aug 25 2005 Giuseppe Ghibò <ghibo@mandriva.com> 1.0-0.20050809.1mdk
- Release: 20050809.

* Sat Aug 06 2005 Giuseppe Ghibò <ghibo@mandriva.com> 1.0-0.20050803.1mdk
- Release: 20050803.

* Tue Jun 28 2005 Giuseppe Ghibò <ghibo@mandriva.com> 1.0-0.20050624.1mdk
- Release: 20050624.
- Removed Patch0 (merged upstream).
- Adapted Patch1.

* Mon Feb 14 2005 Giuseppe Ghibò <ghibo@mandrakesoft.com> 1.0-0.20050209.1mdk
- Release: 20050209.
- Fixed helpdir (Patch2).

* Tue Jan 18 2005 Abel Cheung <deaddog@mandrake.org> 1.0-0.20041231.2mdk
- Don't obsolete/provide pfaedit, pfaedit should still stay (ghibo)
- UTF-8 spec

* Sun Jan 16 2005 Abel Cheung <deaddog@mandrake.org> 1.0-0.20041231.1mdk
- New release
- Updated cidmaps to 2004-12-22
- Obsoletes pfaedit
- Parallel build broken
- P0: fix detection of libxkbui
- P1: Adds DESTDIR support and --mode=* option to libtool calls
- (Seems not working very well, is urw-fonts broken?)

* Thu Aug 26 2004 Giuseppe Ghibò <ghibo@mandrakesoft.com> 1.0-0.20040824.1mdk
- Release: 20040824.
- Removed Patch0, merged upstream.

* Sun Aug 01 2004 Giuseppe Ghibò <ghibo@mandrakesoft.com> 1.0-0.20040703.2mdk
- Added Patch0 to get global variables like $fontversion working correctly.

* Fri Jul 30 2004 Giuseppe Ghibò <ghibo@mandrakesoft.com> 1.0-0.20040703.1mdk
- Initial release.

